###### Malar stripe size and prominence in peregrine falcons vary positively 
###### with solar radiation: ######
###### support for the solar glare hypothesis.  ######

# Vrettos, M., Reynolds, C., Amar, A.

# Author Contact Details

# A. Amar:
#  Email: arjun.amar@uct.ac.za ; arjundevamar@gmail.com 
#  Telephone: +27 (0)21 650 3304
# C. Reynolds:
#  Email: chevonne.reynolds@gmail.com 
#  Telephone: + 27 (0)11 717 6064
# M. Vrettos:
#  Email: vrtmic003@myuct.ac.za
#  Telephone: 071 075 3443



##### CODE ######



##### 1. Read in data and extract scores #####

perfal <- read.csv("Vrettos_et_al_Data.csv")
scores <- perfal[c(23:27)]
summary(scores)



##### 2. Exploratory data analysis #####

# Correlations between variables

library(PerformanceAnalytics)

# Produce correlations plots using the chart.Correlation function in
# PerformanceAnalytics - edited here to remove asterisks indicating significance
# and density lines from histograms.

chart.Correlation <-
  function (R, histogram = TRUE, method=c("pearson", "kendall", "spearman"), ...)
  { # @author R Development Core Team
    # @author modified by Peter Carl
    # Visualization of a Correlation Matrix. On top the (absolute) value of the
    # correlation plus the result of the cor.test as stars. On bottom, the
    # bivariate scatterplots, with a fitted line
    
    x = checkData(R, method="matrix")
    
    if(missing(method)) method=method[1] #only use one
    cormeth <- method
    
    # Published at http://addictedtor.free.fr/graphiques/sources/source_137.R
    panel.cor <- function(x, y, digits=2, prefix="", use="pairwise.complete.obs", method=cormeth, cex.cor, ...)
    {
      usr <- par("usr"); on.exit(par(usr))
      par(usr = c(0, 1, 0, 1))
      r <- cor(x, y, use=use, method=method) # MG: remove abs here
      txt <- format(c(r, 0.123456789), digits=digits)[1]
      txt <- paste(prefix, txt, sep="")
      if(missing(cex.cor)) cex <- 0.8/strwidth(txt)
      
      test <- cor.test(as.numeric(x),as.numeric(y), method=method)
      # borrowed from printCoefmat
      # MG: add abs here and also include a 30% buffer for small numbers
      text(0.5, 0.5, txt, cex = cex * (abs(r) + .3) / 1.3)
    }
    f <- function(t) {
      dnorm(t, mean=mean(x), sd=sd.xts(x) )
    }
    
    #remove method from dotargs
    dotargs <- list(...)
    dotargs$method <- NULL
    rm(method)
    
    hist.panel = function (x, ...=NULL ) {
      par(new = TRUE)
      hist(x,
           col = "light gray",
           probability = TRUE,
           axes = FALSE,
           main = "",
           breaks = "FD")
      #lines(f, col="blue", lwd=1, lty=1) how to add gaussian normal overlay?
      rug(x)
    }
    
    # Draw the chart
    if(histogram)
      pairs(x, gap=0, lower.panel=panel.smooth, upper.panel=panel.cor, diag.panel=hist.panel)
    else
      pairs(x, gap=0, lower.panel=panel.smooth, upper.panel=panel.cor) 
  }

# Correlations between predictor variables

chart.Correlation(perfal[30:32])

# Correlations between malar stripe scores

chart.Correlation(scores)



####### 3. Checking for spatial autocorrelation #######

# Standardize variables

perfal$Solar.Rad.mean.x <- scale(perfal$Solar.Rad.mean)
perfal$Rainfall.mean.x <- scale(perfal$Rainfall.mean)
perfal$MinTemp.mean.x <- scale(perfal$MinTemp.mean)
perfal$Head.Angle.Horizontal.x <- scale(perfal$Head.Angle.Horizontal)
perfal$Head.Angle.Vertical.x <- scale(perfal$Head.Angle.Vertical)
perfal$Vertical.Compression.x <- scale(perfal$Vertical.Compression)

# Basic linear models 

width.global <- lm(Width ~ Solar.Rad.mean.x + Rainfall.mean.x + MinTemp.mean.x 
                    + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                    data=perfal)
contig.global <- lm(Contiguity ~ Solar.Rad.mean.x + Rainfall.mean.x + MinTemp.mean.x 
                    + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                    data=perfal)
prom.global <- lm(Prominence ~ Solar.Rad.mean.x + Rainfall.mean.x + MinTemp.mean.x
                    + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                    data=perfal)
length.global <- lm(Length ~ Solar.Rad.mean.x + Rainfall.mean.x + MinTemp.mean.x 
                    + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                    data=perfal)
elong.global <- lm(Elongation ~ Solar.Rad.mean.x + Rainfall.mean.x + MinTemp.mean.x
                   + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                   data=perfal)

# Check the residuals of these basic models for spatial autocorrelation

library(ape) 

# Width

perfal$Width.model.residuals <- width.global$residuals
Latitude <- perfal$Latitude
Longitude <- perfal$Longitude
perfal = cbind(perfal, Latitude&Longitude) # combine the model residual for each 
# point with the lat and long
dists <- as.matrix(dist(cbind(perfal$Latitude, perfal$Longitude)))
dists.inv <- (1/(dists + 0.000000000000000001)) # add a small constant so not dividing by zero
diag(dists.inv) <- 0
Moran.I(perfal$Width.model.residuals, dists.inv, scaled=T, na.rm=T)

# Contiguity

perfal$Contiguity.model2.residuals <- contig.global$residuals
Latitude <- perfal$Latitude
Longitude <- perfal$Longitude
perfal = cbind(perfal, Latitude&Longitude) # combine the model residual for each 
# point with the lat and long
dists <- as.matrix(dist(cbind(perfal$Latitude, perfal$Longitude)))
dists.inv <- (1/(dists + 0.000000000000000001)) # add a small constant so not dividing by zero
diag(dists.inv) <- 0
Moran.I(perfal$Contiguity.model2.residuals, dists.inv, scaled=T, na.rm=T)

# Prominence

perfal$Prominence.model.residuals <- prom.global$residuals
Latitude <- perfal$Latitude
Longitude <- perfal$Longitude
perfal = cbind(perfal, Latitude&Longitude) # combine the model residual for each 
# point with the lat and long
dists <- as.matrix(dist(cbind(perfal$Latitude, perfal$Longitude)))
dists.inv <- (1/(dists + 0.000000000000000001)) # add a small constant so not dividing by zero
diag(dists.inv) <- 0
Moran.I(perfal$Prominence.model.residuals, dists.inv, scaled=T, na.rm=T)

# Length

perfal$Length.model.residuals <- length.global$residuals
Latitude <- perfal$Latitude
Longitude <- perfal$Longitude
perfal = cbind(perfal, Latitude&Longitude) # combine the model residual for each 
# point with the lat and long
dists <- as.matrix(dist(cbind(perfal$Latitude, perfal$Longitude)))
dists.inv <- (1/(dists + 0.000000000000000001)) # add a small constant so not dividing by zero
diag(dists.inv) <- 0
Moran.I(perfal$Length.model.residuals, dists.inv, scaled=T, na.rm=T)

# Elongation

perfal$Elongation.model.residuals <- elong.global$residuals
Latitude <- perfal$Latitude
Longitude <- perfal$Longitude
perfal = cbind(perfal, Latitude&Longitude) # combine the model residual for each 
# point with the lat and long
dists <- as.matrix(dist(cbind(perfal$Latitude, perfal$Longitude)))
dists.inv <- (1/(dists + 0.000000000000000001)) # add a small constant so not dividing by zero
diag(dists.inv) <- 0
Moran.I(perfal$Elongation.model.residuals, dists.inv, scaled=T, na.rm=T)



####### 4. GLS models #######

library(nlme)
library(lme4)
library(AICcmodavg)

# Width

Cand.mod.width <- list()
Cand.mod.width[[1]] <- gls(Width ~ 1, method = "ML", data=perfal,
                            correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.width[[1]])
Cand.mod.width[[2]] <- gls(Width ~ Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                            method = "ML", data=perfal,
                            correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.width[[2]])
Cand.mod.width[[3]] <- gls(Width ~ Solar.Rad.mean.x 
                            + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                            method = "ML", data=perfal,
                            correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.width[[3]])
Cand.mod.width[[4]] <- gls(Width ~ Rainfall.mean.x
                            + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                            method = "ML", data=perfal,
                            correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.width[[4]])
Cand.mod.width[[5]] <- gls(Width ~ MinTemp.mean.x 
                            + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                            method = "ML", data=perfal,
                            correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.width[[5]])
Cand.mod.width[[6]] <- gls(Width ~ Solar.Rad.mean.x + Rainfall.mean.x 
                            + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                            method = "ML", data=perfal,
                            correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.width[[6]])
Cand.mod.width[[7]] <- gls(Width ~ Solar.Rad.mean.x + MinTemp.mean.x 
                            + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                            method = "ML", data=perfal,
                            correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.width[[7]])
Cand.mod.width[[8]] <- gls(Width ~ Rainfall.mean.x + MinTemp.mean.x 
                            + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                            method = "ML", data=perfal,
                            correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.width[[8]])
Cand.mod.width[[9]] <- gls(Width ~ Solar.Rad.mean.x + Rainfall.mean.x + MinTemp.mean.x 
                            + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                            method = "ML", data=perfal,
                            correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.width[[9]])
Model.names <- c("Null", "Head pos only", "Solar Rad", "Rainfall", "MinTemp", "Solar Rad + Rainfall", "Solar Rad + MinTemp", "Rainfall + MinTemp", "Solar Rad + Rainfall + MinTemp")
aictab(cand.set = Cand.mod.width, modnames = Model.names)

# Model-averaged estimates

modavg(cand.set = Cand.mod.width, modnames = Model.names, parm = "Solar.Rad.mean.x", conf.level = 0.95)
modavg(cand.set = Cand.mod.width, modnames = Model.names, parm = "Rainfall.mean.x", conf.level = 0.95)
modavg(cand.set = Cand.mod.width, modnames = Model.names, parm = "MinTemp.mean.x", conf.level = 0.95)


# Contiguity

Cand.mod.contig <- list()
Cand.mod.contig[[1]] <- gls(Contiguity ~ 1, method = "ML", data=perfal,
                           correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.contig[[1]])
Cand.mod.contig[[2]] <- gls(Contiguity ~ Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                           method = "ML", data=perfal,
                           correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.contig[[2]])
Cand.mod.contig[[3]] <- gls(Contiguity ~ Solar.Rad.mean.x 
                           + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                           method = "ML", data=perfal,
                           correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.contig[[3]])
Cand.mod.contig[[4]] <- gls(Contiguity ~ Rainfall.mean.x
                           + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                           method = "ML", data=perfal,
                           correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.contig[[4]])
Cand.mod.contig[[5]] <- gls(Contiguity ~ MinTemp.mean.x 
                           + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                           method = "ML", data=perfal,
                           correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.contig[[5]])
Cand.mod.contig[[6]] <- gls(Contiguity ~ Solar.Rad.mean.x + Rainfall.mean.x 
                           + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                           method = "ML", data=perfal,
                           correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.contig[[6]])
Cand.mod.contig[[7]] <- gls(Contiguity ~ Solar.Rad.mean.x + MinTemp.mean.x 
                           + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                           method = "ML", data=perfal,
                           correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.contig[[7]])
Cand.mod.contig[[8]] <- gls(Contiguity ~ Rainfall.mean.x + MinTemp.mean.x 
                           + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                           method = "ML", data=perfal,
                           correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.contig[[8]])
Cand.mod.contig[[9]] <- gls(Contiguity ~ Solar.Rad.mean.x + Rainfall.mean.x + MinTemp.mean.x 
                           + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                           method = "ML", data=perfal,
                           correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.contig[[9]])
Model.names <- c("Null", "Head pos only", "Solar Rad", "Rainfall", "MinTemp", "Solar Rad + Rainfall", "Solar Rad + MinTemp", "Rainfall + MinTemp", "Solar Rad + Rainfall + MinTemp")
aictab(cand.set = Cand.mod.contig, modnames = Model.names)

# Model-averaged estimates

modavg(cand.set = Cand.mod.contig, modnames = Model.names, parm = "Solar.Rad.mean.x", conf.level = 0.95)
modavg(cand.set = Cand.mod.contig, modnames = Model.names, parm = "Rainfall.mean.x", conf.level = 0.95)
modavg(cand.set = Cand.mod.contig, modnames = Model.names, parm = "MinTemp.mean.x", conf.level = 0.95)

# Prominence

Cand.mod.prom <- list()
Cand.mod.prom[[1]] <- gls(Prominence ~ 1, method = "ML", data=perfal,
                           correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.prom[[1]])
Cand.mod.prom[[2]] <- gls(Prominence ~ Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                           method = "ML", data=perfal,
                           correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.prom[[2]])
Cand.mod.prom[[3]] <- gls(Prominence ~ Solar.Rad.mean.x 
                           + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                           method = "ML", data=perfal,
                           correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.prom[[3]])
Cand.mod.prom[[4]] <- gls(Prominence ~ Rainfall.mean.x
                           + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                           method = "ML", data=perfal,
                           correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.prom[[4]])
Cand.mod.prom[[5]] <- gls(Prominence ~ MinTemp.mean.x 
                           + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                           method = "ML", data=perfal,
                           correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.prom[[5]])
Cand.mod.prom[[6]] <- gls(Prominence ~ Solar.Rad.mean.x + Rainfall.mean.x 
                           + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                           method = "ML", data=perfal,
                           correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.prom[[6]])
Cand.mod.prom[[7]] <- gls(Prominence ~ Solar.Rad.mean.x + MinTemp.mean.x 
                           + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                           method = "ML", data=perfal,
                           correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.prom[[7]])
Cand.mod.prom[[8]] <- gls(Prominence ~ Rainfall.mean.x + MinTemp.mean.x 
                           + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                           method = "ML", data=perfal,
                           correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.prom[[8]])
Cand.mod.prom[[9]] <- gls(Prominence ~ Solar.Rad.mean.x + Rainfall.mean.x + MinTemp.mean.x 
                           + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                           method = "ML", data=perfal,
                           correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.prom[[9]])
Model.names <- c("Null", "Head pos only", "Solar Rad", "Rainfall", "MinTemp", "Solar Rad + Rainfall", "Solar Rad + MinTemp", "Rainfall + MinTemp", "Solar Rad + Rainfall + MinTemp")
aictab(cand.set = Cand.mod.prom, modnames = Model.names)

# Model-averaged estimates

modavg(cand.set = Cand.mod.prom, modnames = Model.names, parm = "Solar.Rad.mean.x", conf.level = 0.95)
modavg(cand.set = Cand.mod.prom, modnames = Model.names, parm = "Rainfall.mean.x", conf.level = 0.95)
modavg(cand.set = Cand.mod.prom, modnames = Model.names, parm = "MinTemp.mean.x", conf.level = 0.95)

# Length

Cand.mod.length <- list()
Cand.mod.length[[1]] <- gls(Length ~ 1, method = "ML", data=perfal,
                            correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.length[[1]])
Cand.mod.length[[2]] <- gls(Length ~ Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                            method = "ML", data=perfal,
                            correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.length[[2]])
Cand.mod.length[[3]] <- gls(Length ~ Solar.Rad.mean.x 
                            + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                            method = "ML", data=perfal,
                            correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.length[[3]])
Cand.mod.length[[4]] <- gls(Length ~ Rainfall.mean.x
                            + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                            method = "ML", data=perfal,
                            correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.length[[4]])
Cand.mod.length[[5]] <- gls(Length ~ MinTemp.mean.x 
                            + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                            method = "ML", data=perfal,
                            correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.length[[5]])
Cand.mod.length[[6]] <- gls(Length ~ Solar.Rad.mean.x + Rainfall.mean.x 
                            + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                            method = "ML", data=perfal,
                            correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.length[[6]])
Cand.mod.length[[7]] <- gls(Length ~ Solar.Rad.mean.x + MinTemp.mean.x 
                            + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                            method = "ML", data=perfal,
                            correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.length[[7]])
Cand.mod.length[[8]] <- gls(Length ~ Rainfall.mean.x + MinTemp.mean.x 
                            + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                            method = "ML", data=perfal,
                            correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.length[[8]])
Cand.mod.length[[9]] <- gls(Length ~ Solar.Rad.mean.x + Rainfall.mean.x + MinTemp.mean.x 
                            + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                            method = "ML", data=perfal,
                            correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.length[[9]])
Model.names <- c("Null", "Head pos only", "Solar Rad", "Rainfall", "MinTemp", "Solar Rad + Rainfall", "Solar Rad + MinTemp", "Rainfall + MinTemp", "Solar Rad + Rainfall + MinTemp")
aictab(cand.set = Cand.mod.length, modnames = Model.names)

# Model-averaged estimates

modavg(cand.set = Cand.mod.length, modnames = Model.names, parm = "Solar.Rad.mean.x", conf.level = 0.95)
modavg(cand.set = Cand.mod.length, modnames = Model.names, parm = "Rainfall.mean.x", conf.level = 0.95)
modavg(cand.set = Cand.mod.length, modnames = Model.names, parm = "MinTemp.mean.x", conf.level = 0.95)

# Elongation

Cand.mod.elong <- list()
Cand.mod.elong[[1]] <- gls(Elongation ~ 1, method = "ML", data=perfal,
                            correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.elong[[1]])
Cand.mod.elong[[2]] <- gls(Elongation ~ Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                            method = "ML", data=perfal,
                            correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.elong[[2]])
Cand.mod.elong[[3]] <- gls(Elongation ~ Solar.Rad.mean.x 
                            + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                            method = "ML", data=perfal,
                            correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.elong[[3]])
Cand.mod.elong[[4]] <- gls(Elongation ~ Rainfall.mean.x
                            + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                            method = "ML", data=perfal,
                            correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.elong[[4]])
Cand.mod.elong[[5]] <- gls(Elongation ~ MinTemp.mean.x 
                            + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                            method = "ML", data=perfal,
                            correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.elong[[5]])
Cand.mod.elong[[6]] <- gls(Elongation ~ Solar.Rad.mean.x + Rainfall.mean.x 
                            + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                            method = "ML", data=perfal,
                            correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.elong[[6]])
Cand.mod.elong[[7]] <- gls(Elongation ~ Solar.Rad.mean.x + MinTemp.mean.x 
                            + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                            method = "ML", data=perfal,
                            correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.elong[[7]])
Cand.mod.elong[[8]] <- gls(Elongation ~ Rainfall.mean.x + MinTemp.mean.x 
                            + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                            method = "ML", data=perfal,
                            correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.elong[[8]])
Cand.mod.elong[[9]] <- gls(Elongation ~ Solar.Rad.mean.x + Rainfall.mean.x + MinTemp.mean.x 
                            + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                            method = "ML", data=perfal,
                            correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.elong[[9]])
Model.names <- c("Null", "Head pos only", "Solar Rad", "Rainfall", "MinTemp", "Solar Rad + Rainfall", "Solar Rad + MinTemp", "Rainfall + MinTemp", "Solar Rad + Rainfall + MinTemp")
aictab(cand.set = Cand.mod.elong, modnames = Model.names)

# Model-averaged estimates

modavg(cand.set = Cand.mod.elong, modnames = Model.names, parm = "Solar.Rad.mean.x", conf.level = 0.95)
modavg(cand.set = Cand.mod.elong, modnames = Model.names, parm = "Rainfall.mean.x", conf.level = 0.95)
modavg(cand.set = Cand.mod.elong, modnames = Model.names, parm = "MinTemp.mean.x", conf.level = 0.95)



###### 5. Time-filtered analysis ######

# Subset data to include only breeding and resident birds

perfal.v1a <- subset(perfal, Subspecies == "anatum" | Subspecies == "brookei"
                           | Subspecies == "cassini" | Subspecies == "ernesti/nesiotes"
                           | Subspecies == "macropus" | Subspecies == "minor" |
                             Subspecies == "peregrinator" | Subspecies == "peregrinus" |
                             Subspecies == "radama")
perfal.v1b <- subset(perfal, Subspecies == "calidus/tundrius" | Subspecies == "")
perfal.v1b <- subset(perfal.v1b, Month >= 3 & Month <= 8)
perfal.v1 = rbind(perfal.v1a, perfal.v1b)

# GLS models

library(nlme)
library(lme4)
library(AICcmodavg)

# Width

Cand.mod.width.v1 <- list()
Cand.mod.width.v1[[1]] <- gls(Width ~ 1, method = "ML", data=perfal.v1,
                           correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.width.v1[[1]])
Cand.mod.width.v1[[2]] <- gls(Width ~ Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                           method = "ML", data=perfal.v1,
                           correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.width.v1[[2]])
Cand.mod.width.v1[[3]] <- gls(Width ~ Solar.Rad.mean.x 
                           + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                           method = "ML", data=perfal.v1,
                           correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.width.v1[[3]])
Cand.mod.width.v1[[4]] <- gls(Width ~ Rainfall.mean.x
                           + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                           method = "ML", data=perfal.v1,
                           correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.width.v1[[4]])
Cand.mod.width.v1[[5]] <- gls(Width ~ MinTemp.mean.x 
                           + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                           method = "ML", data=perfal.v1,
                           correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.width.v1[[5]])
Cand.mod.width.v1[[6]] <- gls(Width ~ Solar.Rad.mean.x + Rainfall.mean.x 
                           + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                           method = "ML", data=perfal.v1,
                           correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.width.v1[[6]])
Cand.mod.width.v1[[7]] <- gls(Width ~ Solar.Rad.mean.x + MinTemp.mean.x 
                           + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                           method = "ML", data=perfal.v1,
                           correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.width.v1[[7]])
Cand.mod.width.v1[[8]] <- gls(Width ~ Rainfall.mean.x + MinTemp.mean.x 
                           + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                           method = "ML", data=perfal.v1,
                           correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.width.v1[[8]])
Cand.mod.width.v1[[9]] <- gls(Width ~ Solar.Rad.mean.x + Rainfall.mean.x + MinTemp.mean.x 
                           + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                           method = "ML", data=perfal.v1,
                           correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.width.v1[[9]])
Model.names <- c("Null", "Head pos only", "Solar Rad", "Rainfall", "MinTemp", "Solar Rad + Rainfall", "Solar Rad + MinTemp", "Rainfall + MinTemp", "Solar Rad + Rainfall + MinTemp")
aictab(cand.set = Cand.mod.width.v1, modnames = Model.names)

# Mode-averaged estimates - time-filtered analysis

modavg(cand.set = Cand.mod.width.v1, modnames = Model.names, parm = "Solar.Rad.mean.x", conf.level = 0.95)
modavg(cand.set = Cand.mod.width.v1, modnames = Model.names, parm = "Rainfall.mean.x", conf.level = 0.95)
modavg(cand.set = Cand.mod.width.v1, modnames = Model.names, parm = "MinTemp.mean.x", conf.level = 0.95)

# Contiguity

Cand.mod.contig.v1 <- list()
Cand.mod.contig.v1[[1]] <- gls(Contiguity ~ 1, method = "ML", data=perfal.v1,
                            correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.contig.v1[[1]])
Cand.mod.contig.v1[[2]] <- gls(Contiguity ~ Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                            method = "ML", data=perfal.v1,
                            correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.contig.v1[[2]])
Cand.mod.contig.v1[[3]] <- gls(Contiguity ~ Solar.Rad.mean.x 
                            + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                            method = "ML", data=perfal.v1,
                            correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.contig.v1[[3]])
Cand.mod.contig.v1[[4]] <- gls(Contiguity ~ Rainfall.mean.x
                            + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                            method = "ML", data=perfal.v1,
                            correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.contig.v1[[4]])
Cand.mod.contig.v1[[5]] <- gls(Contiguity ~ MinTemp.mean.x 
                            + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                            method = "ML", data=perfal.v1,
                            correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.contig.v1[[5]])
Cand.mod.contig.v1[[6]] <- gls(Contiguity ~ Solar.Rad.mean.x + Rainfall.mean.x 
                            + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                            method = "ML", data=perfal.v1,
                            correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.contig.v1[[6]])
Cand.mod.contig.v1[[7]] <- gls(Contiguity ~ Solar.Rad.mean.x + MinTemp.mean.x 
                            + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                            method = "ML", data=perfal.v1,
                            correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.contig.v1[[7]])
Cand.mod.contig.v1[[8]] <- gls(Contiguity ~ Rainfall.mean.x + MinTemp.mean.x 
                            + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                            method = "ML", data=perfal.v1,
                            correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.contig.v1[[8]])
Cand.mod.contig.v1[[9]] <- gls(Contiguity ~ Solar.Rad.mean.x + Rainfall.mean.x + MinTemp.mean.x 
                            + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                            method = "ML", data=perfal.v1,
                            correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.contig.v1[[9]])
Model.names <- c("Null", "Head pos only", "Solar Rad", "Rainfall", "MinTemp", "Solar Rad + Rainfall", "Solar Rad + MinTemp", "Rainfall + MinTemp", "Solar Rad + Rainfall + MinTemp")
aictab(cand.set = Cand.mod.contig.v1, modnames = Model.names)

# Model-averaged estimates - time-filtered analysis

modavg(cand.set = Cand.mod.contig.v1, modnames = Model.names, parm = "Solar.Rad.mean.x", conf.level = 0.95)
modavg(cand.set = Cand.mod.contig.v1, modnames = Model.names, parm = "Rainfall.mean.x", conf.level = 0.95)
modavg(cand.set = Cand.mod.contig.v1, modnames = Model.names, parm = "MinTemp.mean.x", conf.level = 0.95)

# Prominence

Cand.mod.prom.v1 <- list()
Cand.mod.prom.v1[[1]] <- gls(Prominence ~ 1, method = "ML", data=perfal.v1,
                          correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.prom.v1[[1]])
Cand.mod.prom.v1[[2]] <- gls(Prominence ~ Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                          method = "ML", data=perfal.v1,
                          correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.prom.v1[[2]])
Cand.mod.prom.v1[[3]] <- gls(Prominence ~ Solar.Rad.mean.x 
                          + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                          method = "ML", data=perfal.v1,
                          correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.prom.v1[[3]])
Cand.mod.prom.v1[[4]] <- gls(Prominence ~ Rainfall.mean.x
                          + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                          method = "ML", data=perfal.v1,
                          correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.prom.v1[[4]])
Cand.mod.prom.v1[[5]] <- gls(Prominence ~ MinTemp.mean.x 
                          + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                          method = "ML", data=perfal.v1,
                          correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.prom.v1[[5]])
Cand.mod.prom.v1[[6]] <- gls(Prominence ~ Solar.Rad.mean.x + Rainfall.mean.x 
                          + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                          method = "ML", data=perfal.v1,
                          correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.prom.v1[[6]])
Cand.mod.prom.v1[[7]] <- gls(Prominence ~ Solar.Rad.mean.x + MinTemp.mean.x 
                          + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                          method = "ML", data=perfal.v1,
                          correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.prom.v1[[7]])
Cand.mod.prom.v1[[8]] <- gls(Prominence ~ Rainfall.mean.x + MinTemp.mean.x 
                          + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                          method = "ML", data=perfal.v1,
                          correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.prom.v1[[8]])
Cand.mod.prom.v1[[9]] <- gls(Prominence ~ Solar.Rad.mean.x + Rainfall.mean.x + MinTemp.mean.x 
                          + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                          method = "ML", data=perfal.v1,
                          correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.prom.v1[[9]])
Model.names <- c("Null", "Head pos only", "Solar Rad", "Rainfall", "MinTemp", "Solar Rad + Rainfall", "Solar Rad + MinTemp", "Rainfall + MinTemp", "Solar Rad + Rainfall + MinTemp")
aictab(cand.set = Cand.mod.prom.v1, modnames=Model.names)

# Model-averaged estimates - time-filtered analysis

modavg(cand.set = Cand.mod.prom.v1, modnames = Model.names, parm = "Solar.Rad.mean.x", conf.level = 0.95)
modavg(cand.set = Cand.mod.prom.v1, modnames = Model.names, parm = "Rainfall.mean.x", conf.level = 0.95)
modavg(cand.set = Cand.mod.prom.v1, modnames = Model.names, parm = "MinTemp.mean.x", conf.level = 0.95)

# Length

Cand.mod.length.v1 <- list()
Cand.mod.length.v1[[1]] <- gls(Length ~ 1, method = "ML", data=perfal.v1,
                             correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.length.v1[[1]])
Cand.mod.length.v1[[2]] <- gls(Length ~ Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                             method = "ML", data=perfal.v1,
                             correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.length.v1[[2]])
Cand.mod.length.v1[[3]] <- gls(Length ~ Solar.Rad.mean.x 
                             + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                             method = "ML", data=perfal.v1,
                             correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.length.v1[[3]])
Cand.mod.length.v1[[4]] <- gls(Length ~ Rainfall.mean.x
                             + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                             method = "ML", data=perfal.v1,
                             correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.length.v1[[4]])
Cand.mod.length.v1[[5]] <- gls(Length ~ MinTemp.mean.x 
                             + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                             method = "ML", data=perfal.v1,
                             correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.length.v1[[5]])
Cand.mod.length.v1[[6]] <- gls(Length ~ Solar.Rad.mean.x + Rainfall.mean.x 
                             + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                             method = "ML", data=perfal.v1,
                             correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.length.v1[[6]])
Cand.mod.length.v1[[7]] <- gls(Length ~ Solar.Rad.mean.x + MinTemp.mean.x 
                             + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                             method = "ML", data=perfal.v1,
                             correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.length.v1[[7]])
Cand.mod.length.v1[[8]] <- gls(Length ~ Rainfall.mean.x + MinTemp.mean.x 
                             + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                             method = "ML", data=perfal.v1,
                             correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.length.v1[[8]])
Cand.mod.length.v1[[9]] <- gls(Length ~ Solar.Rad.mean.x + Rainfall.mean.x + MinTemp.mean.x 
                             + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                             method = "ML", data=perfal.v1,
                             correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.length.v1[[9]])
Model.names <- c("Null", "Head pos only", "Solar Rad", "Rainfall", "MinTemp", "Solar Rad + Rainfall", "Solar Rad + MinTemp", "Rainfall + MinTemp", "Solar Rad + Rainfall + MinTemp")
aictab(cand.set = Cand.mod.length.v1, modnames = Model.names)

# Model-averaged estimates - time-filtered analysis

modavg(cand.set = Cand.mod.length.v1, modnames = Model.names, parm = "Solar.Rad.mean.x", conf.level = 0.95)
modavg(cand.set = Cand.mod.length.v1, modnames = Model.names, parm = "Rainfall.mean.x", conf.level = 0.95)
modavg(cand.set = Cand.mod.length.v1, modnames = Model.names, parm = "MinTemp.mean.x", conf.level = 0.95)

# Elongation

Cand.mod.elong.v1 <- list()
Cand.mod.elong.v1[[1]] <- gls(Elongation ~ 1, method = "ML", data=perfal.v1,
                           correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.elong.v1[[1]])
Cand.mod.elong.v1[[2]] <- gls(Elongation ~ Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                           method = "ML", data=perfal.v1,
                           correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.elong.v1[[2]])
Cand.mod.elong.v1[[3]] <- gls(Elongation ~ Solar.Rad.mean.x 
                           + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                           method = "ML", data=perfal.v1,
                           correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.elong.v1[[3]])
Cand.mod.elong.v1[[4]] <- gls(Elongation ~ Rainfall.mean.x
                           + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                           method = "ML", data=perfal.v1,
                           correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.elong.v1[[4]])
Cand.mod.elong.v1[[5]] <- gls(Elongation ~ MinTemp.mean.x 
                           + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                           method = "ML", data=perfal.v1,
                           correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.elong.v1[[5]])
Cand.mod.elong.v1[[6]] <- gls(Elongation ~ Solar.Rad.mean.x + Rainfall.mean.x 
                           + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                           method = "ML", data=perfal.v1,
                           correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.elong.v1[[6]])
Cand.mod.elong.v1[[7]] <- gls(Elongation ~ Solar.Rad.mean.x + MinTemp.mean.x 
                           + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                           method = "ML", data=perfal.v1,
                           correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.elong.v1[[7]])
Cand.mod.elong.v1[[8]] <- gls(Elongation ~ Rainfall.mean.x + MinTemp.mean.x 
                           + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                           method = "ML", data=perfal.v1,
                           correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.elong.v1[[8]])
Cand.mod.elong.v1[[9]] <- gls(Elongation ~ Solar.Rad.mean.x + Rainfall.mean.x + MinTemp.mean.x 
                           + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                           method = "ML", data=perfal.v1,
                           correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.elong.v1[[9]])
Model.names <- c("Null", "Head pos only", "Solar Rad", "Rainfall", "MinTemp", "Solar Rad + Rainfall", "Solar Rad + MinTemp", "Rainfall + MinTemp", "Solar Rad + Rainfall + MinTemp")
aictab(cand.set = Cand.mod.elong.v1, modnames = Model.names)

# Model-averaged estimates

modavg(cand.set = Cand.mod.elong.v1, modnames = Model.names, parm = "Solar.Rad.mean.x", conf.level = 0.95)
modavg(cand.set = Cand.mod.elong.v1, modnames = Model.names, parm = "Rainfall.mean.x", conf.level = 0.95)
modavg(cand.set = Cand.mod.elong.v1, modnames = Model.names, parm = "MinTemp.mean.x", conf.level = 0.95)


###### 5. Filtered analysis excluding the US and Canada ######

# Subset data to exclude the US and Canada

perfal.v2 <- subset(perfal, Country!="United States" & Country!="Canada")

# GLS models

library(nlme)
library(lme4)
library(AICcmodavg)

# Width

Cand.mod.width.v2 <- list()
Cand.mod.width.v2[[1]] <- gls(Width ~ 1, method = "ML", data=perfal.v2,
                            correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.width.v2[[1]])
Cand.mod.width.v2[[2]] <- gls(Width ~ Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                            method = "ML", data=perfal.v2,
                            correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.width.v2[[2]])
Cand.mod.width.v2[[3]] <- gls(Width ~ Solar.Rad.mean.x 
                            + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                            method = "ML", data=perfal.v2,
                            correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.width.v2[[3]])
Cand.mod.width.v2[[4]] <- gls(Width ~ Rainfall.mean.x
                            + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                            method = "ML", data=perfal.v2,
                            correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.width.v2[[4]])
Cand.mod.width.v2[[5]] <- gls(Width ~ MinTemp.mean.x 
                            + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                            method = "ML", data=perfal.v2,
                            correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.width.v2[[5]])
Cand.mod.width.v2[[6]] <- gls(Width ~ Solar.Rad.mean.x + Rainfall.mean.x 
                            + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                            method = "ML", data=perfal.v2,
                            correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.width.v2[[6]])
Cand.mod.width.v2[[7]] <- gls(Width ~ Solar.Rad.mean.x + MinTemp.mean.x 
                            + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                            method = "ML", data=perfal.v2,
                            correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.width.v2[[7]])
Cand.mod.width.v2[[8]] <- gls(Width ~ Rainfall.mean.x + MinTemp.mean.x 
                            + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                            method = "ML", data=perfal.v2,
                            correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.width.v2[[8]])
Cand.mod.width.v2[[9]] <- gls(Width ~ Solar.Rad.mean.x + Rainfall.mean.x + MinTemp.mean.x 
                            + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                            method = "ML", data=perfal.v2,
                            correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.width.v2[[9]])
Model.names <- c("Null", "Head pos only", "Solar Rad", "Rainfall", "MinTemp", "Solar Rad + Rainfall", "Solar Rad + MinTemp", "Rainfall + MinTemp", "Solar Rad + Rainfall + MinTemp")
aictab(cand.set = Cand.mod.width.v2, modnames = Model.names)

# Model-averaged estimates - excluding the US and Canada

modavg(cand.set = Cand.mod.width.v2, modnames = Model.names, parm = "Solar.Rad.mean.x", conf.level = 0.95)
modavg(cand.set = Cand.mod.width.v2, modnames = Model.names, parm = "Rainfall.mean.x", conf.level = 0.95)
modavg(cand.set = Cand.mod.width.v2, modnames = Model.names, parm = "MinTemp.mean.x", conf.level = 0.95)

# Contiguity

Cand.mod.contig.v2 <- list()
Cand.mod.contig.v2[[1]] <- gls(Contiguity ~ 1, method = "ML", data=perfal.v2,
                             correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.contig.v2[[1]])
Cand.mod.contig.v2[[2]] <- gls(Contiguity ~ Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                             method = "ML", data=perfal.v2,
                             correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.contig.v2[[2]])
Cand.mod.contig.v2[[3]] <- gls(Contiguity ~ Solar.Rad.mean.x 
                             + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                             method = "ML", data=perfal.v2,
                             correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.contig.v2[[3]])
Cand.mod.contig.v2[[4]] <- gls(Contiguity ~ Rainfall.mean.x
                             + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                             method = "ML", data=perfal.v2,
                             correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.contig.v2[[4]])
Cand.mod.contig.v2[[5]] <- gls(Contiguity ~ MinTemp.mean.x 
                             + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                             method = "ML", data=perfal.v2,
                             correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.contig.v2[[5]])
Cand.mod.contig.v2[[6]] <- gls(Contiguity ~ Solar.Rad.mean.x + Rainfall.mean.x 
                             + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                             method = "ML", data=perfal.v2,
                             correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.contig.v2[[6]])
Cand.mod.contig.v2[[7]] <- gls(Contiguity ~ Solar.Rad.mean.x + MinTemp.mean.x 
                             + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                             method = "ML", data=perfal.v2,
                             correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.contig.v2[[7]])
Cand.mod.contig.v2[[8]] <- gls(Contiguity ~ Rainfall.mean.x + MinTemp.mean.x 
                             + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                             method = "ML", data=perfal.v2,
                             correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.contig.v2[[8]])
Cand.mod.contig.v2[[9]] <- gls(Contiguity ~ Solar.Rad.mean.x + Rainfall.mean.x + MinTemp.mean.x 
                             + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                             method = "ML", data=perfal.v2,
                             correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.contig.v2[[9]])
Model.names <- c("Null", "Head pos only", "Solar Rad", "Rainfall", "MinTemp", "Solar Rad + Rainfall", "Solar Rad + MinTemp", "Rainfall + MinTemp", "Solar Rad + Rainfall + MinTemp")
aictab(cand.set = Cand.mod.contig.v2, modnames = Model.names)

# Model-averaged estimates - excluding the US and Canada

modavg(cand.set = Cand.mod.contig.v2, modnames = Model.names, parm = "Solar.Rad.mean.x", conf.level = 0.95)
modavg(cand.set = Cand.mod.contig.v2, modnames = Model.names, parm = "Rainfall.mean.x", conf.level = 0.95)
modavg(cand.set = Cand.mod.contig.v2, modnames = Model.names, parm = "MinTemp.mean.x", conf.level = 0.95)

# Prominence

Cand.mod.prom.v2 <- list()
Cand.mod.prom.v2[[1]] <- gls(Prominence ~ 1, method = "ML", data=perfal.v2,
                           correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.prom.v2[[1]])
Cand.mod.prom.v2[[2]] <- gls(Prominence ~ Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                           method = "ML", data=perfal.v2,
                           correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.prom.v2[[2]])
Cand.mod.prom.v2[[3]] <- gls(Prominence ~ Solar.Rad.mean.x 
                           + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                           method = "ML", data=perfal.v2,
                           correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.prom.v2[[3]])
Cand.mod.prom.v2[[4]] <- gls(Prominence ~ Rainfall.mean.x
                           + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                           method = "ML", data=perfal.v2,
                           correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.prom.v2[[4]])
Cand.mod.prom.v2[[5]] <- gls(Prominence ~ MinTemp.mean.x 
                           + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                           method = "ML", data=perfal.v2,
                           correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.prom.v2[[5]])
Cand.mod.prom.v2[[6]] <- gls(Prominence ~ Solar.Rad.mean.x + Rainfall.mean.x 
                           + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                           method = "ML", data=perfal.v2,
                           correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.prom.v2[[6]])
Cand.mod.prom.v2[[7]] <- gls(Prominence ~ Solar.Rad.mean.x + MinTemp.mean.x 
                           + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                           method = "ML", data=perfal.v2,
                           correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.prom.v2[[7]])
Cand.mod.prom.v2[[8]] <- gls(Prominence ~ Rainfall.mean.x + MinTemp.mean.x 
                           + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                           method = "ML", data=perfal.v2,
                           correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.prom.v2[[8]])
Cand.mod.prom.v2[[9]] <- gls(Prominence ~ Solar.Rad.mean.x + Rainfall.mean.x + MinTemp.mean.x 
                           + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                           method = "ML", data=perfal.v2,
                           correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.prom.v2[[9]])
Model.names <- c("Null", "Head pos only", "Solar Rad", "Rainfall", "MinTemp", "Solar Rad + Rainfall", "Solar Rad + MinTemp", "Rainfall + MinTemp", "Solar Rad + Rainfall + MinTemp")
aictab(cand.set = Cand.mod.prom.v2)

# Model-averaged estimates - excluding the US and Canada

modavg(cand.set = Cand.mod.prom.v2, modnames = Model.names, parm = "Solar.Rad.mean.x", conf.level = 0.95)
modavg(cand.set = Cand.mod.prom.v2, modnames = Model.names, parm = "Rainfall.mean.x", conf.level = 0.95)
modavg(cand.set = Cand.mod.prom.v2, modnames = Model.names, parm = "MinTemp.mean.x", conf.level = 0.95)

# Length

Cand.mod.length.v2 <- list()
Cand.mod.length.v2[[1]] <- gls(Length ~ 1, method = "ML", data=perfal.v2,
                             correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.length.v2[[1]])
Cand.mod.length.v2[[2]] <- gls(Length ~ Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                             method = "ML", data=perfal.v2,
                             correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.length.v2[[2]])
Cand.mod.length.v2[[3]] <- gls(Length ~ Solar.Rad.mean.x 
                             + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                             method = "ML", data=perfal.v2,
                             correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.length.v2[[3]])
Cand.mod.length.v2[[4]] <- gls(Length ~ Rainfall.mean.x
                             + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                             method = "ML", data=perfal.v2,
                             correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.length.v2[[4]])
Cand.mod.length.v2[[5]] <- gls(Length ~ MinTemp.mean.x 
                             + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                             method = "ML", data=perfal.v2,
                             correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.length.v2[[5]])
Cand.mod.length.v2[[6]] <- gls(Length ~ Solar.Rad.mean.x + Rainfall.mean.x 
                             + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                             method = "ML", data=perfal.v2,
                             correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.length.v2[[6]])
Cand.mod.length.v2[[7]] <- gls(Length ~ Solar.Rad.mean.x + MinTemp.mean.x 
                             + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                             method = "ML", data=perfal.v2,
                             correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.length.v2[[7]])
Cand.mod.length.v2[[8]] <- gls(Length ~ Rainfall.mean.x + MinTemp.mean.x 
                             + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                             method = "ML", data=perfal.v2,
                             correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.length.v2[[8]])
Cand.mod.length.v2[[9]] <- gls(Length ~ Solar.Rad.mean.x + Rainfall.mean.x + MinTemp.mean.x 
                             + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                             method = "ML", data=perfal.v2,
                             correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.length.v2[[9]])
Model.names <- c("Null", "Head pos only", "Solar Rad", "Rainfall", "MinTemp", "Solar Rad + Rainfall", "Solar Rad + MinTemp", "Rainfall + MinTemp", "Solar Rad + Rainfall + MinTemp")
aictab(cand.set = Cand.mod.length.v2, modnames = Model.names)

# Model-averaged estimates - excluding the US and Canada

modavg(cand.set = Cand.mod.length.v2, modnames = Model.names, parm = "Solar.Rad.mean.x", conf.level = 0.95)
modavg(cand.set = Cand.mod.length.v2, modnames = Model.names, parm = "Rainfall.mean.x", conf.level = 0.95)
modavg(cand.set = Cand.mod.length.v2, modnames = Model.names, parm = "MinTemp.mean.x", conf.level = 0.95)

# Elongation

Cand.mod.elong.v2 <- list()
Cand.mod.elong.v2[[1]] <- gls(Elongation ~ 1, method = "ML", data=perfal.v2,
                              correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.elong.v2[[1]])
Cand.mod.elong.v2[[2]] <- gls(Elongation ~ Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                              method = "ML", data=perfal.v2,
                              correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.elong.v2[[2]])
Cand.mod.elong.v2[[3]] <- gls(Elongation ~ Solar.Rad.mean.x 
                              + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                              method = "ML", data=perfal.v2,
                              correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.elong.v2[[3]])
Cand.mod.elong.v2[[4]] <- gls(Elongation ~ Rainfall.mean.x
                              + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                              method = "ML", data=perfal.v2,
                              correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.elong.v2[[4]])
Cand.mod.elong.v2[[5]] <- gls(Elongation ~ MinTemp.mean.x 
                              + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                              method = "ML", data=perfal.v2,
                              correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.elong.v2[[5]])
Cand.mod.elong.v2[[6]] <- gls(Elongation ~ Solar.Rad.mean.x + Rainfall.mean.x 
                              + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                              method = "ML", data=perfal.v2,
                              correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.elong.v2[[6]])
Cand.mod.elong.v2[[7]] <- gls(Elongation ~ Solar.Rad.mean.x + MinTemp.mean.x 
                              + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                              method = "ML", data=perfal.v2,
                              correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.elong.v2[[7]])
Cand.mod.elong.v2[[8]] <- gls(Elongation ~ Rainfall.mean.x + MinTemp.mean.x 
                              + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                              method = "ML", data=perfal.v2,
                              correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.elong.v2[[8]])
Cand.mod.elong.v2[[9]] <- gls(Elongation ~ Solar.Rad.mean.x + Rainfall.mean.x + MinTemp.mean.x 
                              + Head.Angle.Horizontal.x + Head.Angle.Vertical.x + Vertical.Compression.x,
                              method = "ML", data=perfal.v2,
                              correlation=corExp(form = ~Latitude+Longitude))
summary(Cand.mod.elong.v2[[9]])
Model.names <- c("Null", "Head pos only", "Solar Rad", "Rainfall", "MinTemp", "Solar Rad + Rainfall", "Solar Rad + MinTemp", "Rainfall + MinTemp", "Solar Rad + Rainfall + MinTemp")
aictab(cand.set = Cand.mod.elong.v2, modnames = Model.names)

# Model-averaged estimates

modavg(cand.set = Cand.mod.elong.v2, modnames = Model.names, parm = "Solar.Rad.mean.x", conf.level = 0.95)
modavg(cand.set = Cand.mod.elong.v2, modnames = Model.names, parm = "Rainfall.mean.x", conf.level = 0.95)
modavg(cand.set = Cand.mod.elong.v2, modnames = Model.names, parm = "MinTemp.mean.x", conf.level = 0.95)



###### 7. Quantitative Validation of Scores and Shape Analysis #####

# Calculate correlations between quantitative measurements and scores

perfal.v3 <- subset(perfal, ImageJ=="TRUE")
scores <- perfal.v3[c(23:27)]
shape.measurements <- perfal.v3[c(37:45)]
shape.corrs <- cbind(scores, shape.measurements)

library(PerformanceAnalytics)

chart.Correlation <-
  function (R, histogram = TRUE, method=c("pearson", "kendall", "spearman"), ...)
  { # @author R Development Core Team
    # @author modified by Peter Carl
    # Visualization of a Correlation Matrix. On top the (absolute) value of the
    # correlation plus the result of the cor.test as stars. On botttom, the
    # bivariate scatterplots, with a fitted line
    
    x = checkData(R, method="matrix")
    
    if(missing(method)) method=method[1] #only use one
    cormeth <- method
    
    # Published at http://addictedtor.free.fr/graphiques/sources/source_137.R
    panel.cor <- function(x, y, digits=2, prefix="", use="pairwise.complete.obs", method=cormeth, cex.cor, ...)
    {
      usr <- par("usr"); on.exit(par(usr))
      par(usr = c(0, 1, 0, 1))
      r <- cor(x, y, use=use, method=method) # MG: remove abs here
      txt <- format(c(r, 0.123456789), digits=digits)[1]
      txt <- paste(prefix, txt, sep="")
      if(missing(cex.cor)) cex <- 0.8/strwidth(txt)
      
      test <- cor.test(as.numeric(x),as.numeric(y), method=method)
      # borrowed from printCoefmat
      Signif <- symnum(test$p.value, corr = FALSE, na = FALSE,
                       cutpoints = c(0, 0.001, 0.01, 0.05, 0.1, 1),
                       symbols = c("***", "**", "*", ".", " "))
      # MG: add abs here and also include a 30% buffer for small numbers
      text(0.5, 0.5, txt, cex = cex * (abs(r) + 1) / 1.3)
      text(.8, .8, Signif, cex=cex, col=2)
    }
    f <- function(t) {
      dnorm(t, mean=mean(x), sd=sd.xts(x) )
    }
    
    #remove method from dotargs
    dotargs <- list(...)
    dotargs$method <- NULL
    rm(method)
    
    hist.panel = function (x, ...=NULL ) {
      par(new = TRUE)
      hist(x,
           col = "light gray",
           probability = TRUE,
           axes = FALSE,
           main = "",
           breaks = "FD")
      #lines(f, col="blue", lwd=1, lty=1) how to add gaussian normal overlay?
      rug(x)
    }
    
    # Draw the chart
    if(histogram)
      pairs(x, gap=0, lower.panel=panel.smooth, upper.panel=panel.cor, diag.panel=hist.panel)
    else
      pairs(x, gap=0, lower.panel=panel.smooth, upper.panel=panel.cor) 
  }

chart.Correlation(shape.corrs, method="pearson")


###### 8. Figures ######


## World Map

library(rworldmap)
library(rworldxtra)
library(ggplot2)

# Load world map dataset

world <- map_data("world")
summary(world)

# Join peregrine data to world map dataset

perfal$Country <- as.factor(perfal$Country)
perfal$mapWidth <- 1.8^perfal$Width # This is to make the differences between the bubble sizes easier to see on the map
perfal.map <- joinCountryData2Map(perfal
                                  ,joinCode = "NAME"
                                  ,nameJoinColumn = "Country"
                                  ,mapResolution = "high"
                                  ,verbose = TRUE)

# Map of solar radiation

library(viridis)
library(RColorBrewer)

mapDevice() # create world map shaped window
mapParams <- mapCountryData(perfal.map
                            ,nameColumnToPlot='Solar.Rad.mean'
                            ,addLegend = FALSE
                            ,colourPalette ="heat")
do.call(addMapLegend, c(mapParams,
                        horizontal = FALSE,
                        legendLabels="limits",
                        labelFontSize=1,
                        legendMar=45,
                        legendShrink = 0.2,
                        legendWidth=2))

# Add bubbles representing malar stripe width and sample size

perfal.map$Country.N[39] <- 50 # This sets the sample size for the US and Canada
perfal.map$Country.N[236] <- 50 # to 50 - done so that the large sample sizes of
# these countries will not skew the assignment
# of colours for the colour legend.

colourPalette <- c("#9ECAE1", "#6BAED6", "#4292C6", "#2171B5", "#08519C", "#08306B")
mapBubbles(dF=perfal.map
           ,nameZSize="mapWidth"
           ,nameZColour="Country.N"
           ,catMethod = "pretty"
           ,symbolSize = 1.8
           ,addLegend = TRUE
           ,addColourLegend = TRUE
           ,add = TRUE
           ,colourPalette=adjustcolor(palette(colourPalette), alpha.f = 0.9))


## North America State Map

library(rworldmap)
library(raster)
library(maptools)

# Download state maps of USA and Canada

usa <- getData("GADM", country = "United States", level = 1)
can <- getData("GADM", country = "Canada", level = 1)

# Join peregrine data to USA and Canada state maps

perfal.usa <- subset(perfal, Country == "United States")
perfal.can <- subset(perfal, Country == "Canada")
perfal.usamap<- joinData2Map(perfal.usa,nameMap="usa",
                             nameJoinIDMap="NAME_1",
                             nameJoinColumnData="State")
perfal.canmap <- joinData2Map(perfal.can,nameMap="can",
                              nameJoinIDMap="NAME_1",
                              nameJoinColumnData="State",
                              verbose=TRUE)

# Combine USA and Canada map data

perfal.nammap <- rbind(perfal.usamap, perfal.canmap, makeUniqueIDs = TRUE)

# Map of solar radiation

library(viridis)
library(RColorBrewer)

mapDevice() # create North America map shaped window
mapParams <- mapCountryData(perfal.nammap
                            ,nameColumnToPlot='Solar.Rad.mean'
                            ,colourPalette = "heat"
                            ,addLegend = FALSE)
do.call(addMapLegend, c(mapParams,
                        horizontal = FALSE,
                        legendLabels="limits",
                        labelFontSize=1,
                        legendMar = 20,
                        legendShrink = 0.2,
                        legendWidth=2))

# Add bubbles representing malar stripe width and sample size

colourPalette <- c("#9ECAE1", "#6BAED6", "#4292C6", "#2171B5", "#08519C", "#08306B")
mapBubbles(dF=perfal.nammap
           ,nameZSize="mapWidth"
           ,nameZColour="State.N"
           ,catMethod = "pretty"
           ,addLegend = TRUE
           ,symbolSize = 1
           ,add=TRUE
           ,colourPalette=adjustcolor(palette(colourPalette), alpha.f = 0.9)
           ,addColourLegend = TRUE)


## Forest plot showing GLS model outputs

library(ggplot2)

# Extract model-averaged estimates and confidence intervals

# Width

width.solar <- modavg(cand.set = Cand.mod.width, modnames = Model.names, parm = "Solar.Rad.mean.x", conf.level = 0.95)
width.rain <- modavg(cand.set = Cand.mod.width, modnames = Model.names, parm = "Rainfall.mean.x", conf.level = 0.95)
width.temp <- modavg(cand.set = Cand.mod.width, modnames = Model.names, parm = "MinTemp.mean.x", conf.level = 0.95)
width.means <- c(width.solar$Mod.avg.beta, width.rain$Mod.avg.beta, width.temp$Mod.avg.beta)
width.mins <- c(width.solar$Lower.CL, width.rain$Lower.CL, width.temp$Lower.CL)
width.maxes <- c(width.solar$Upper.CL, width.rain$Upper.CL, width.temp$Upper.CL)
predictors <- c("Solar Radiation", "Rainfall", "Minimum Temperature")
var.name <- c("Width", "Width", "Width")
width.avgs <- data.frame(Variable = var.name, Mean=width.means, Upper=width.maxes, Lower=width.mins,
                         Predictor=predictors)

# Contiguity

contig.solar <- modavg(cand.set = Cand.mod.contig, modnames = Model.names, parm = "Solar.Rad.mean.x", conf.level = 0.95)
contig.rain <- modavg(cand.set = Cand.mod.contig, modnames = Model.names, parm = "Rainfall.mean.x", conf.level = 0.95)
contig.temp <- modavg(cand.set = Cand.mod.contig, modnames = Model.names, parm = "MinTemp.mean.x", conf.level = 0.95)
contig.means <- c(contig.solar$Mod.avg.beta, contig.rain$Mod.avg.beta, contig.temp$Mod.avg.beta)
contig.mins <- c(contig.solar$Lower.CL, contig.rain$Lower.CL, contig.temp$Lower.CL)
contig.maxes <- c(contig.solar$Upper.CL, contig.rain$Upper.CL, contig.temp$Upper.CL)
predictors <- c("Solar Radiation", "Rainfall", "Minimum Temperature")
var.name <- c("Contiguity", "Contiguity", "Contiguity")
contig.avgs <- data.frame(Variable = var.name, Mean=contig.means, Upper=contig.maxes, Lower=contig.mins,
                          Predictor=predictors)

# Prominence

prom.solar <- modavg(cand.set = Cand.mod.prom, modnames = Model.names, parm = "Solar.Rad.mean.x", conf.level = 0.95)
prom.rain <- modavg(cand.set = Cand.mod.prom, modnames = Model.names, parm = "Rainfall.mean.x", conf.level = 0.95)
prom.temp <- modavg(cand.set = Cand.mod.prom, modnames = Model.names, parm = "MinTemp.mean.x", conf.level = 0.95)
prom.means <- c(prom.solar$Mod.avg.beta, prom.rain$Mod.avg.beta, prom.temp$Mod.avg.beta)
prom.mins <- c(prom.solar$Lower.CL, prom.rain$Lower.CL, prom.temp$Lower.CL)
prom.maxes <- c(prom.solar$Upper.CL, prom.rain$Upper.CL, prom.temp$Upper.CL)
predictors <- c("Solar Radiation", "Rainfall", "Minimum Temperature")
var.name <- c("Prominence", "Prominence", "Prominence")
prom.avgs <- data.frame(Variable = var.name, Mean=prom.means, Upper=prom.maxes, Lower=prom.mins,
                        Predictor=predictors)

# Length

length.solar <- modavg(cand.set = Cand.mod.length, modnames = Model.names, parm = "Solar.Rad.mean.x", conf.level = 0.95)
length.rain <- modavg(cand.set = Cand.mod.length, modnames = Model.names, parm = "Rainfall.mean.x", conf.level = 0.95)
length.temp <- modavg(cand.set = Cand.mod.length, modnames = Model.names, parm = "MinTemp.mean.x", conf.level = 0.95)
length.means <- c(length.solar$Mod.avg.beta, length.rain$Mod.avg.beta, length.temp$Mod.avg.beta)
length.mins <- c(length.solar$Lower.CL, length.rain$Lower.CL, length.temp$Lower.CL)
length.maxes <- c(length.solar$Upper.CL, length.rain$Upper.CL, length.temp$Upper.CL)
predictors <- c("Solar Radiation", "Rainfall", "Minimum Temperature")
var.name <- c("Length", "Length", "Length")
length.avgs <- data.frame(Variable = var.name, Mean=length.means, Upper=length.maxes, Lower=length.mins,
                          Predictor=predictors)

# Elongation

elong.solar <- modavg(cand.set = Cand.mod.elong, modnames = Model.names, parm = "Solar.Rad.mean.x", conf.level = 0.95)
elong.rain <- modavg(cand.set = Cand.mod.elong, modnames = Model.names, parm = "Rainfall.mean.x", conf.level = 0.95)
elong.temp <- modavg(cand.set = Cand.mod.elong, modnames = Model.names, parm = "MinTemp.mean.x", conf.level = 0.95)
elong.means <- c(elong.solar$Mod.avg.beta, elong.rain$Mod.avg.beta, elong.temp$Mod.avg.beta)
elong.mins <- c(elong.solar$Lower.CL, elong.rain$Lower.CL, elong.temp$Lower.CL)
elong.maxes <- c(elong.solar$Upper.CL, elong.rain$Upper.CL, elong.temp$Upper.CL)
predictors <- c("Solar Radiation", "Rainfall", "Minimum Temperature")
var.name <- c("Elongation", "Elongation", "Elongation")
elong.avgs <- data.frame(Variable = var.name, Mean=elong.means, Upper=elong.maxes, Lower=elong.mins,
                          Predictor=predictors)


perfal.avgs <- rbind(width.avgs, contig.avgs, prom.avgs, length.avgs)
perfal.avgs$Variable <- factor(perfal.avgs$Variable, levels = c("Width", "Contiguity", "Prominence", "Length"))

# Create forest plot - first four variables

forest.plot.main=ggplot(perfal.avgs, aes(y = Predictor, x = Mean, xmin=Lower, xmax=Upper))+
  geom_point(color = 'black', size=4)+
  geom_errorbarh(aes(xmin=Lower, xmax=Upper, height=0.2))+
  scale_x_continuous(limits=c(-0.4,0.4), name='Estimate')+
  ylab('')+
  geom_vline(xintercept=0, color='black', linetype='dashed')+
  facet_wrap(~Variable,strip.position="right",nrow=4,scales = "free_y") +
  theme()+
  theme_bw()+
  theme(panel.grid.major=element_blank(),
        panel.grid.minor=element_blank(),
        axis.line=element_line(),
        text=element_text(size=24,face="bold"),
        legend.position='none')
axis.ticks.y=element_blank()
axis.text.x=element_text(face="bold")
axis.title=element_text(size=24,face="bold")
strip.text.y = element_text(hjust=0,vjust = 1,angle=270,face="bold")
axis.text.y=element_text(hjust=0,vjust = 1,angle=0)
forest.plot.main

# Create forest plot - elongation (adjusted axis for different variable scale)

forest.plot.elong=ggplot(elong.avgs, aes(y = Predictor, x = Mean, xmin=Lower, xmax=Upper))+
  geom_point(color = 'black', size=4)+
  geom_errorbarh(aes(xmin=Lower, xmax=Upper, height=0.2))+
  scale_x_continuous(limits=c(-0.1,0.1), name='Estimate')+
  ylab('')+
  geom_vline(xintercept=0, color='black', linetype='dashed')+
  facet_wrap(~Variable,strip.position="right",nrow=1,scales = "free_y") +
  theme()+
  theme_bw()+
  theme(panel.grid.major=element_blank(),
        panel.grid.minor=element_blank(),
        axis.line=element_line(),
        text=element_text(size=24,face="bold"),
        legend.position='none')
axis.ticks.y=element_blank()
axis.text.x=element_text(face="bold")
axis.title=element_text(size=24,face="bold")
strip.text.y = element_text(hjust=0,vjust = 1,angle=270,face="bold")
axis.text.y=element_text(hjust=0,vjust = 1,angle=0)
forest.plot.elong


# Scatterplots showing linear relationships (supplementary material)

library(ggplot2)
library(scales)
library(gridExtra)

# Width

width.plot <- ggplot(aes(x=Solar.Rad.mean, y=Width), data=perfal) +
  geom_jitter(shape=16, alpha=0.2, position=position_jitter(0.2))+
  labs(x = expression(paste("Average Annual Solar Radiation (W/", m^2, ")")), y = "Malar Stripe Width (Score)", col=expression(paste("Solar Radiation (W/", m^2, ")"))) +
  theme(panel.background = element_rect(fill = "white"),
        axis.line.x.top = element_line(color = "black"),
        axis.line.x.bottom = element_line(color = "black"),
        axis.line.y = element_line(color = "black"),
        axis.title.x = element_text(size = 20),
        axis.text = element_text(size=16),
        axis.title.y = element_text(size = 20),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.border = element_rect(colour = "black", fill=NA, size=1))
width.plot <- width.plot + geom_smooth(method="lm", fill="lightblue", formula = y ~ x)
width.plot

# Contiguity

contig.plot <- ggplot(aes(x=Solar.Rad.mean, y=Contiguity), data=perfal) +
  geom_jitter(shape=16, alpha=0.2, position=position_jitter(0.2))+ 
  labs(x = expression(paste("Average Annual Solar Radiation (W/", m^2, ")")), y = "Malar Stripe Contiguity (Score)", col=expression(paste("Solar Radiation (W/", m^2, ")"))) +
  theme(panel.background = element_rect(fill = "white"),
        axis.line.x.top = element_line(color = "black"),
        axis.line.x.bottom = element_line(color = "black"),
        axis.line.y = element_line(color = "black"),
        axis.title.x = element_text(size = 20),
        axis.text = element_text(size=16),
        axis.title.y = element_text(size = 20),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.border = element_rect(colour = "black", fill=NA, size=1))
contig.plot <- contig.plot + geom_smooth(method="lm", fill="lightblue", formula = y ~ x)
contig.plot

# Prominence

prom.plot <- ggplot(aes(x=Solar.Rad.mean, y=Prominence), data=perfal) +
  geom_jitter(shape=16, alpha=0.2, position=position_jitter(0.2))+
  labs(x = expression(paste("Average Annual Solar Radiation (W/", m^2, ")")), y = "Malar Stripe Prominence (Score)", col=expression(paste("Solar Radiation (W/", m^2, ")"))) +
  theme(panel.background = element_rect(fill = "white"),
        axis.line.x.top = element_line(color = "black"),
        axis.line.x.bottom = element_line(color = "black"),
        axis.line.y = element_line(color = "black"),
        axis.title.x = element_text(size = 20),
        axis.text = element_text(size=16),
        axis.title.y = element_text(size = 20),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.border = element_rect(colour = "black", fill=NA, size=1))
prom.plot <- prom.plot + geom_smooth(method="lm", fill="lightblue", formula = y ~ x)
prom.plot

# Elongation

elong.plot <- ggplot(aes(x=Solar.Rad.mean, y=Elongation), data=perfal) +
  geom_jitter(shape=16, alpha=0.2, position=position_jitter(0.2))+
  labs(x = expression(paste("Average Annual Solar Radiation (W/", m^2, ")")), y = "Malar Stripe Elongation (Length Score/Width Score)", col=expression(paste("Solar Radiation (W/", m^2, ")"))) +
  theme(panel.background = element_rect(fill = "white"),
        axis.line.x.top = element_line(color = "black"),
        axis.line.x.bottom = element_line(color = "black"),
        axis.line.y = element_line(color = "black"),
        axis.title.x = element_text(size = 12),
        axis.text = element_text(size=12),
        axis.title.y = element_text(size = 12),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.border = element_rect(colour = "black", fill=NA, size=1))
elong.plot <- elong.plot + geom_smooth(method="lm", fill="lightblue", formula = y ~ x) +
              scale_y_continuous(trans='log', breaks = c(0.4, 1, 2.8))
elong.plot